import {
	Card,
	CardContent,
	CardDescription,
	CardHeader,
	CardTitle
} from "@/components/ui/card";
import { Tabs, TabsContent } from "@/components/ui/tabs";
import { Header } from "@/components/layout/header";
import { Main } from "@/components/layout/main";
import { ProfileDropdown } from "@/components/profile-dropdown";
import { Search } from "@/components/search";
import { ThemeSwitch } from "@/components/theme-switch";
import { Overview } from "./components/overview";
import { RecentSales } from "./components/recent-sales";
import { useUsers } from "@/hooks/useUsers";
import { usePurchases } from "@/hooks/usePurchases";
import { Purchase } from "@/api/mock/models";
import { formatCurrency } from "@/utils/format-currency";
import { useShop } from "@/hooks/useShop";

export default function Dashboard() {
	const { data: users } = useUsers();
	const { shop } = useShop();
	const { data: purchases } = usePurchases();

	const totalRevenue = purchases?.reduce((sum, p) => sum + p.total, 0) ?? 0;

	const totalCustomers =
		users?.filter((u) => u.user_role === "customer").length ?? 0;

	const totalSales = purchases?.length ?? 0;

	const averageOrderValue = totalSales ? totalRevenue / totalSales : 0;

	function getMonthlyRevenue(purchases: Purchase[]) {
		
		const result: Record<string, number> = {};
		purchases.forEach((p) => {
			const date = new Date(p.date_purchased);
			const month = date.toLocaleString("en-US", { month: "short" });
			result[month] = (result[month] || 0) + p.total;
		});
		return result;
	}

	const revenueFormatted = formatCurrency(totalRevenue, shop?.currency ?? "USD");

	const avgFormatted = formatCurrency(averageOrderValue, shop?.currency ?? "USD");

	return (
		<>
			<Header>
				<Search />
				<div className="ml-auto flex items-center space-x-4">
					<ThemeSwitch />
					<ProfileDropdown />
				</div>
			</Header>

			<Main>
				<div className="mb-2 flex items-center justify-between space-y-2">
					<h1 className="text-2xl font-bold tracking-tight">Dashboard</h1>
				</div>
				<Tabs
					orientation="vertical"
					defaultValue="overview"
					className="space-y-4">
					<TabsContent value="overview" className="space-y-4">
						<div className="grid gap-4 sm:grid-cols-2 lg:grid-cols-4">
							{/* Total Revenue */}
							<Card>
								<CardHeader className="flex flex-row items-center justify-between space-y-0 pb-2">
									<CardTitle className="text-sm font-medium">
										Total Revenue
									</CardTitle>
									<svg
										xmlns="http://www.w3.org/2000/svg"
										viewBox="0 0 24 24"
										fill="none"
										stroke="currentColor"
										strokeLinecap="round"
										strokeLinejoin="round"
										strokeWidth="2"
										className="h-4 w-4 text-muted-foreground">
										<path d="M12 2v20M17 5H9.5a3.5 3.5 0 0 0 0 7h5a3.5 3.5 0 0 1 0 7H6" />
									</svg>
								</CardHeader>
								<CardContent>
									<div className="text-2xl font-bold">{revenueFormatted}</div>
									<p className="text-xs text-muted-foreground">
										Based on all time data
									</p>
								</CardContent>
							</Card>

							{/* Total Customers */}
							<Card>
								<CardHeader className="flex flex-row items-center justify-between space-y-0 pb-2">
									<CardTitle className="text-sm font-medium">
										Total Customers
									</CardTitle>
									<svg
										xmlns="http://www.w3.org/2000/svg"
										viewBox="0 0 24 24"
										fill="none"
										stroke="currentColor"
										strokeLinecap="round"
										strokeLinejoin="round"
										strokeWidth="2"
										className="h-4 w-4 text-muted-foreground">
										<circle cx="12" cy="12" r="10" />
										<path d="M16 14a4 4 0 0 0-8 0" />
										<line x1="12" y1="6" x2="12" y2="6" />
									</svg>
								</CardHeader>
								<CardContent>
									<div className="text-2xl font-bold">{totalCustomers}</div>
									<p className="text-xs text-muted-foreground">
										All-time registered customers
									</p>
								</CardContent>
							</Card>

							{/* Sales */}
							<Card>
								<CardHeader className="flex flex-row items-center justify-between space-y-0 pb-2">
									<CardTitle className="text-sm font-medium">Sales</CardTitle>
									<svg
										xmlns="http://www.w3.org/2000/svg"
										viewBox="0 0 24 24"
										fill="none"
										stroke="currentColor"
										strokeLinecap="round"
										strokeLinejoin="round"
										strokeWidth="2"
										className="h-4 w-4 text-muted-foreground">
										<rect width="20" height="14" x="2" y="5" rx="2" />
										<path d="M2 10h20" />
									</svg>
								</CardHeader>
								<CardContent>
									<div className="text-2xl font-bold">+{totalSales}</div>
									<p className="text-xs text-muted-foreground">
										Total purchases made
									</p>
								</CardContent>
							</Card>

							{/* Average Order Value */}
							<Card>
								<CardHeader className="flex flex-row items-center justify-between space-y-0 pb-2">
									<CardTitle className="text-sm font-medium">
										Average Order Value
									</CardTitle>
									<svg
										xmlns="http://www.w3.org/2000/svg"
										viewBox="0 0 24 24"
										fill="none"
										stroke="currentColor"
										strokeLinecap="round"
										strokeLinejoin="round"
										strokeWidth="2"
										className="h-4 w-4 text-muted-foreground">
										<path d="M3 3v18h18" />
										<path d="M7 12h10M7 16h10M7 8h10" />
									</svg>
								</CardHeader>
								<CardContent>
									<div className="text-2xl font-bold">{avgFormatted}</div>
									<p className="text-xs text-muted-foreground">
										Across all sales
									</p>
								</CardContent>
							</Card>
						</div>

						{/* Overview + Recent Sales */}
						<div className="grid grid-cols-1 gap-4 lg:grid-cols-7">
							<Card className="col-span-1 lg:col-span-4">
								<CardHeader>
									<CardTitle>Overview</CardTitle>
								</CardHeader>
								<CardContent className="pl-2">
									<Overview
										data={Object.entries(
											getMonthlyRevenue(purchases ?? [])
										).map(([name, total]) => ({ name, total }))}
									/>
								</CardContent>
							</Card>
							<Card className="col-span-1 lg:col-span-3">
								<CardHeader>
									<CardTitle>Recent Sales</CardTitle>
									<CardDescription>
										You made {totalSales} sales overall.
									</CardDescription>
								</CardHeader>
								<CardContent>
									<RecentSales />
								</CardContent>
							</Card>
						</div>
					</TabsContent>
				</Tabs>
			</Main>
		</>
	);
}
